# feeluown 虾米音乐插件

## 安装

```sh
pip3 install fuo-xiami
```

## changelog
### 0.1.2 (2019-03-18)
- 修复获取歌手歌曲时进入死循环

### 0.1.1 (2019-03-18)
- 当请求因为 token 失效而失败时，自动重试

### 0.1 (2019-03-18)
- 用户登录，歌曲/歌手/专辑详情获取等基本功能
